# Table of Contents

- [configuring-e-mail-channel](<./configuring-e-mail-channel.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Configuring the E-Mail Channel](<./Configuring-the-E-Mail-Channel.md>)
  - [Workspace Notifications](<./Configuring-the-E-Mail-Channel/Workspace-Notifications.md>)
  - [Customizing the Email Template](<./Configuring-the-E-Mail-Channel/Customizing-the-Email-Template.md>)
  - [Blocked Email Addresses](<./Configuring-the-E-Mail-Channel/Blocked-Email-Addresses.md>)
